@@ -8,7 +8,7 @@ Jug.IO module
 - write_task_out: write out results, possibly with metadata.
 '''
 
-from .task import TaskGenerator, Task
+from .task import TaskGenerator
 
 class NoLoad(object):
     def __init__(self, t):
@@ -87,18 +87,24 @@ def write_metadata(result, metadata_fname, metadata_format='yaml'):
 
 # Console status table output
 
-import textwrap
-
 def print_task_summary_table(options, groups):
     """Print task summary table given tasks groups.
 
     groups - [(group_title, {(task_name, count)})] grouped summary of tasks.
     """
+    if options.short:
+        for name,gv in groups:
+            options.print_out("{0}:  {1} tasks".format(name, sum(gv.values())))
+        n = sum([sum(gv.values()) for _,gv in groups])
+        options.print_out("** Total: {0} tasks.".format(n))
+        return
+
+    import textwrap
     num_groups = len(groups)
 
-    names = list()
+    names = set()
     for _, group_data in groups:
-        names.extend(n for n in group_data.keys() if not n in names) 
+        names.update(group_data.keys())
 
     termsize, termheight = get_terminal_size()
     name_width = termsize - (num_groups * 12) - 2
@@ -109,7 +115,7 @@ def print_task_summary_table(options, groups):
     options.print_out(line_format % tuple([g for g, _ in groups] + ["Task name"]))
     options.print_out('-' * format_size)
 
-    for n in names:
+    for n in sorted(names):
         name_lines = textwrap.wrap(n, width=name_width - 4)
         options.print_out(line_format % tuple([g[n] for _, g in groups] + name_lines[:1]))
 
@@ -127,8 +133,7 @@ import shlex
 import struct
 import platform
 import subprocess
- 
- 
+
 def get_terminal_size():
     """ get_terminal_size()
      - get width and height of console
