@@ -1,3 +1,6 @@
+import inspect
+import os
+
 import jug.jug
 from jug.tests.utils import simple_execute
 from jug.backends.dict_store import dict_store
@@ -5,6 +8,11 @@ from .task_reset import task_reset
 from jug.task import describe
 from nose.tools import with_setup
 
+
+_jugdir = os.path.abspath(inspect.getfile(inspect.currentframe()))
+_jugdir = os.path.join(os.path.dirname(_jugdir), 'jugfiles')
+
+
 def remove_files(flist, dlist):
     def teardown():
         from os import unlink
@@ -23,7 +31,7 @@ def remove_files(flist, dlist):
 
 @task_reset
 def test_describe():
-    jugfile = 'jug/tests/jugfiles/simple.py'
+    jugfile = os.path.join(_jugdir, 'simple.py')
     store, space = jug.jug.init(jugfile, 'dict_store')
     simple_execute()
     t = space['vals'][0]
@@ -33,7 +41,7 @@ def test_describe():
 @remove_files(['x.pkl', 'x.meta.yaml', 'x.meta.json'], ['testing_TO_DELETE.jugdata'])
 @task_reset
 def test_describe():
-    jugfile = 'jug/tests/jugfiles/write_with_meta.py'
+    jugfile = os.path.join(_jugdir, 'write_with_meta.py')
     store, space = jug.jug.init(jugfile, 'testing_TO_DELETE.jugdata')
     simple_execute()
     x = space['x']
