@@ -1,27 +1,37 @@
+import inspect
+import os
+
 from jug.subcommands import status
 from jug.tests.task_reset import task_reset
 from jug.tests.utils import simple_execute
 from jug.options import default_options
 import jug
 
+
+_jugdir = os.path.abspath(inspect.getfile(inspect.currentframe()))
+_jugdir = os.path.join(os.path.dirname(_jugdir), 'jugfiles')
+
+
 @task_reset
 def test_nocache():
-    store, space = jug.jug.init('jug/tests/jugfiles/simple.py', 'dict_store')
+    jugfile = os.path.join(_jugdir, 'simple.py')
+    store, space = jug.jug.init(jugfile, 'dict_store')
     simple_execute()
 
     options = default_options.copy()
     options.jugdir = store
-    options.jugfile = 'jug/tests/jugfiles/simple.py'
+    options.jugfile = jugfile
     options.verbose = 'quiet'
     assert status.status(options) == 8 * 4
 
 @task_reset
 def test_cache():
-    store, space = jug.jug.init('jug/tests/jugfiles/simple.py', 'dict_store')
+    jugfile = os.path.join(_jugdir, 'simple.py')
+    store, space = jug.jug.init(jugfile, 'dict_store')
 
     options = default_options.copy()
     options.jugdir = store
-    options.jugfile = 'jug/tests/jugfiles/simple.py'
+    options.jugfile = jugfile
     options.verbose = 'quiet'
     options.status_mode = 'cached'
     options.status_cache_file = ':memory:'
@@ -32,11 +42,12 @@ def test_cache():
 
 @task_reset
 def test_cache_bvalue():
-    store, space = jug.jug.init('jug/tests/jugfiles/bvalue.py', 'dict_store')
+    jugfile = os.path.join(_jugdir, 'bvalue.py')
+    store, space = jug.jug.init(jugfile, 'dict_store')
 
     options = default_options.copy()
     options.jugdir = store
-    options.jugfile = 'jug/tests/jugfiles/bvalue.py'
+    options.jugfile = jugfile
     options.verbose = 'quiet'
     options.status_mode = 'cached'
     options.status_cache_file = ':memory:'
